@@ -6,7 +6,7 @@ use Carp;
 use Scalar::Util qw( blessed );
 use LucyX::Search::AnyTermCompiler;
 
-our $VERSION = '0.004';
+our $VERSION = '0.005';
 
 =head1 NAME
 
@@ -34,7 +34,6 @@ methods are documented here.
 
 # Inside-out member vars
 my %field;
-my %term_limit;
 
 =head2 new( I<args> )
 
@@ -46,12 +45,10 @@ for C<field>.
 sub new {
     my ( $class, %args ) = @_;
     my $field = delete $args{field};
-    my $limit = delete $args{term_limit} || $ENV{LUCYX_TERM_LIMIT} || 1000;
     my $self  = $class->SUPER::new(%args);
     confess("'field' param is required")
         unless defined $field;
-    $field{$$self}      = $field;
-    $term_limit{$$self} = $limit;
+    $field{$$self} = $field;
     return $self;
 }
 
@@ -66,7 +63,6 @@ sub get_field { my $self = shift; return $field{$$self} }
 sub DESTROY {
     my $self = shift;
     delete $field{$$self};
-    delete $term_limit{$$self};
     $self->SUPER::DESTROY;
 }
 
@@ -109,10 +105,7 @@ sub make_compiler {
     my $self = shift;
     my %args = @_;
     $args{parent} = $self;
-    return LucyX::Search::AnyTermCompiler->new(
-        term_limit => $term_limit{$$self},
-        %args
-    );
+    return LucyX::Search::AnyTermCompiler->new(%args);
 
     # TODO should our compiler call this in make_matcher() ?
 
